@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2016-2023 Red Hat, Inc.
+ * Copyright (c) 2016-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,9 @@
  */
 package org.fedoraproject.xmvn.metadata;
 
+import java.nio.file.Path;
+import java.util.Map;
+
 import org.fedoraproject.xmvn.artifact.Artifact;
 
 /**
@@ -32,4 +35,12 @@ public interface MetadataResult
      *         artifact
      */
     ArtifactMetadata getMetadataFor( Artifact artifact );
+
+    /**
+     * Return a read-only {@link Map} that contains every found metadata file {@link Path}s and a corresponding
+     * {@link PackageMetadata}.
+     * 
+     * @return package metadata map, never {@code null}
+     */
+    Map<Path, PackageMetadata> getPackageMetadataMap();
 }
