@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2014-2023 Red Hat, Inc.
+ * Copyright (c) 2014-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
  */
 package org.fedoraproject.xmvn.metadata.impl;
 
+import java.nio.file.Path;
 import java.util.Collections;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
@@ -38,13 +39,17 @@ class DefaultMetadataResult
 {
     private final Logger logger;
 
+    private final Map<Path, PackageMetadata> packageMetadataMap;
+
     private final Map<Artifact, ArtifactMetadata> artifactMap = new LinkedHashMap<>();
 
-    public DefaultMetadataResult( Logger logger, List<PackageMetadata> metadataList, boolean ignoreDuplicates )
+    public DefaultMetadataResult( Logger logger, Map<Path, PackageMetadata> packageMetadataMap,
+                                  boolean ignoreDuplicates )
     {
         this.logger = logger;
+        this.packageMetadataMap = packageMetadataMap;
 
-        for ( PackageMetadata metadata : metadataList )
+        for ( PackageMetadata metadata : packageMetadataMap.values() )
         {
             for ( ArtifactMetadata installedArtifact : metadata.getArtifacts() )
             {
@@ -123,4 +128,10 @@ class DefaultMetadataResult
     {
         return artifactMap.get( artifact );
     }
+
+    @Override
+    public Map<Path, PackageMetadata> getPackageMetadataMap()
+    {
+        return Collections.unmodifiableMap( packageMetadataMap );
+    }
 }
