@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2014-2023 Red Hat, Inc.
+ * Copyright (c) 2014-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,6 +30,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.stream.Stream;
 
 import org.junit.jupiter.api.Test;
 import org.xmlunit.assertj3.XmlAssert;
@@ -146,9 +147,9 @@ public class BasicDeployerTest
 
     private boolean runningAsRoot()
     {
-        try
+        try ( Stream<String> lines = Files.lines( Paths.get( "/proc/self/status" ) ) )
         {
-            return Files.lines( Paths.get( "/proc/self/status" ) ).map( s ->
+            return lines.map( s ->
             {
                 Matcher matcher = PROCESS_UID_PATTERN.matcher( s );
 
