@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2016-2023 Red Hat, Inc.
+ * Copyright (c) 2016-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -218,7 +218,7 @@ public class JavadocMojo
         long nNonAutomatic = nModular - nAutomatic;
         if ( nAutomatic > 0 && nNonAutomatic > 0 )
         {
-            logger.warn( "Found {} non-automacit modules (with module-info) and {} automatic modules."
+            logger.warn( "Found {} non-automatic modules (with module-info) and {} automatic modules."
                 + " Mixing automatic and non-automatic modules is not supported. Javadoc is likely to fail."
                 + " For more info see debug output.", nNonAutomatic, nAutomatic );
         }
@@ -234,7 +234,7 @@ public class JavadocMojo
     private void addOpt( String name )
     {
         options.add( name );
-        logger.debug( "Javadc option: {}", name );
+        logger.debug( "Javadoc option: {}", name );
     }
 
     private boolean addOpt( String name, String value )
@@ -371,6 +371,7 @@ public class JavadocMojo
         addOpt( "-d", outputDir );
         addOpt( "-docencoding", docencoding, "UTF-8" );
         addOpt( "-doctitle", "Javadoc for package XXX" );
+        addOpt( "-notimestamp" );
 
         if ( !addOpt( "--release", release ) )
         {
@@ -435,6 +436,8 @@ public class JavadocMojo
                          StandardOpenOption.TRUNCATE_EXISTING );
 
             invokeJavadoc( outputDir );
+
+            Files.deleteIfExists( outputDir.resolve( "args" ) );
         }
         catch ( IOException | InterruptedException e )
         {
