@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -69,7 +69,7 @@ public final class JarUtils
      */
     public static boolean containsNativeCode( Path jarPath )
     {
-        try ( ZipFile jar = new ZipFile( jarPath.toFile() ) )
+        try ( ZipFile jar = ZipFile.builder().setPath( jarPath ).get() )
         {
             Enumeration<ZipArchiveEntry> entries = jar.getEntries();
             while ( entries.hasMoreElements() )
@@ -131,7 +131,7 @@ public final class JarUtils
      */
     public static boolean usesNativeCode( Path jarPath )
     {
-        try ( ZipFile jar = new ZipFile( jarPath.toFile() ) )
+        try ( ZipFile jar = ZipFile.builder().setPath( jarPath ).get() )
         {
             Enumeration<ZipArchiveEntry> entries = jar.getEntries();
             while ( entries.hasMoreElements() )
@@ -220,7 +220,7 @@ public final class JarUtils
     public static void injectManifest( Path targetJar, Artifact artifact )
     {
         LOGGER.trace( "Trying to inject manifest to {}", artifact );
-        try ( ZipFile jar = new ZipFile( targetJar.toFile() ) )
+        try ( ZipFile jar = ZipFile.builder().setPath( targetJar ).get() )
         {
             if ( jar.getEntry( MANIFEST_PATH ) == null )
             {
@@ -246,15 +246,20 @@ public final class JarUtils
         }
         LOGGER.trace( "Created backup file {}", backupPath );
 
-        try ( ZipFile jar = new ZipFile( backupPath.toFile() );
+        try ( ZipFile jar = ZipFile.builder().setPath( backupPath ).get();
                         ZipArchiveOutputStream os = new ZipArchiveOutputStream( targetJar.toFile() ) )
         {
-            try ( InputStream mfIs = jar.getInputStream( jar.getEntry( MANIFEST_PATH ) ) )
+            ZipArchiveEntry jarEntry = jar.getEntry( MANIFEST_PATH );
+            try ( InputStream mfIs = jar.getInputStream( jarEntry ) )
             {
                 Manifest mf = new Manifest( mfIs );
                 updateManifest( artifact, mf );
                 // write manifest
                 ZipArchiveEntry newManifestEntry = new ZipArchiveEntry( MANIFEST_PATH );
+                if ( jarEntry != null )
+                {
+                    newManifestEntry.setTime( jarEntry.getTime() );
+                }
                 os.putArchiveEntry( newManifestEntry );
                 mf.write( os );
                 os.closeArchiveEntry();
