@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2014-2023 Red Hat, Inc.
+ * Copyright (c) 2014-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -163,14 +163,6 @@ public abstract class AbstractInstallerTest
         assertDescriptorEquals( mfiles, expected );
     }
 
-    private void unifyUuids( NodeList nodes )
-    {
-        for ( int i = 0; i < nodes.getLength(); i++ )
-        {
-            nodes.item( i ).setTextContent( "uuid-placeholder" );
-        }
-    }
-
     protected void assertMetadataEqual( Path expected, Path actual )
         throws Exception
     {
@@ -192,9 +184,6 @@ public abstract class AbstractInstallerTest
             }
         }
 
-        unifyUuids( expectedXml.getElementsByTagName( "uuid" ) );
-        unifyUuids( actualXml.getElementsByTagName( "uuid" ) );
-
         XmlAssert.assertThat( expectedXml ).and( actualXml ).ignoreComments().ignoreWhitespace().areSimilar();
     }
 }
