@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2014-2023 Red Hat, Inc.
+ * Copyright (c) 2014-2024 Red Hat, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@ import static org.easymock.EasyMock.isA;
 import static org.easymock.EasyMock.replay;
 import static org.easymock.EasyMock.verify;
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.fail;
 
 import java.nio.file.Files;
@@ -127,7 +126,6 @@ public class ArtifactInstallerTest
         assertEquals( 1, metadata.getArtifacts().size() );
         ArtifactMetadata actualArtifact = metadata.getArtifacts().get( 0 );
         assertEquals( "ns", actualArtifact.getNamespace() );
-        assertNotNull( actualArtifact.getUuid() );
 
         assertEquals( 2, pkg.getFiles().size() );
         Iterator<File> iterator = pkg.getFiles().iterator();
